@@ -142,11 +142,12 @@ start-up modules.
    use PDLA::IO::Misc;
    use PDLA::IO::FITS;
    use PDLA::IO::Pic;
+   use PDLA::IO::Storable;
    use PDLA::Lvalue;
 
 =cut
 
-our $VERSION = "2.013009";
+our $VERSION = "2.014000";
 
 # Main loader of standard PDLA package
 
@@ -180,6 +181,10 @@ use PDLA::IO::Pic;           # rpic/wpic
 
 use PDLA::Config;
 
+# Load this to avoid mysterious Storable segfaults
+
+use PDLA::IO::Storable;
+
 EOD
 
 die $@ if $@;
